@@ -195,8 +195,8 @@ def write_NXsample(
         data_type (Tuple[str, int]): Images or events.
         osc_scan (Dict[str, ArrayLike]): Rotation scan. If writing events, this is just a (start, end) tuple.
         transl_scan (Dict[str, ArrayLike], optional): Scan along the xy axes at sample. Defaults to None.
-        sample_depends_on (str): Axis on which the sample depends on. If absent, the depends_on field will be set to the last axis listed in the goniometer. Defaults to None.
-        sample_details (Dict[str, Any]): General information about the sample, eg. name, temperature.
+        sample_depends_on (str, optional): Axis on which the sample depends on. If absent, the depends_on field will be set to the last axis listed in the goniometer. Defaults to None.
+        sample_details (Dict[str, Any], optional): General information about the sample, eg. name, temperature.
     """
     NXclass_logger.info("Start writing NXsample and NXtransformations.")
     # Create NXsample group, unless it already exists, in which case just open it.
@@ -641,8 +641,10 @@ def write_NXdetector(
             )
 
     # Detector distance
-    nxdetector.create_dataset("distance", data=dist.magnitude)
-    create_attributes(nxdetector["distance"], ("units",), (format(dist.units, "~")))
+    nxdetector.create_dataset("distance", data=dist.to("m").magnitude)
+    create_attributes(
+        nxdetector["distance"], ("units",), (format(dist.to("m").units, "~"))
+    )
 
     # Check if there are any remaining datasets to be written (usually from the meta file but not always)
     others = [
@@ -838,10 +840,10 @@ def write_NXcollection(
     if "TRISTAN" in detector["description"].upper():  # or data_type[1] == "events":
         tick = ureg.Quantity(detector["detector_tick"])
         grp.create_dataset("detector_tick", data=tick.magnitude)
-        grp["detector_tick"].attrs["units"] = format(tick.units, "~")
+        grp["detector_tick"].attrs["units"] = np.string_(format(tick.units, "~"))
         freq = ureg.Quantity(detector["detector_frequency"])
         grp.create_dataset("detector_frequency", data=freq.magnitude)
-        grp["detector_frequency"].attrs["units"] = format(freq.units, "~")
+        grp["detector_frequency"].attrs["units"] = np.string_(format(freq.units, "~"))
         grp.create_dataset(
             "timeslice_rollover_bits", data=detector["timeslice_rollover"]
         )
